@@ -1,6 +1,6 @@
 package XML::XPath::Function;
 
-$VERSION = '1.47';
+$VERSION = '1.48';
 
 use XML::XPath::Number;
 use XML::XPath::Literal;
@@ -9,6 +9,21 @@ use XML::XPath::NodeSet;
 use XML::XPath::Node::Attribute;
 use strict; use warnings;
 
+=head1 NAME
+
+XML::XPath::Functions - implementations of XPath functions
+
+=head1 DESCRIPTION
+
+XPath 1.0 and some later functions are supported.
+
+Note that functions that take regular expressions use Perl-syntax REs,
+not the language described in the XPath spec.
+
+=head1 FUNCTIONS
+
+=cut
+
 sub new {
     my $class = shift;
     my ($pp, $name, $params) = @_;
@@ -76,7 +91,41 @@ sub _execute {
 # XML::XPath::NodeSet
 # XML::XPath::Boolean
 
-### NODESET FUNCTIONS ###
+=head2 NODESET FUNCTIONS
+
+=over
+
+=item *
+
+C<last()>
+
+=item *
+
+C<position()>
+
+=item *
+
+C<count()>
+
+=item *
+
+C<id()>
+
+=item *
+
+C<local-name()>
+
+=item *
+
+C<name()>
+
+=item *
+
+C<namespace-uri()>
+
+=back
+
+=cut
 
 sub last {
     my $self = shift;
@@ -176,7 +225,71 @@ sub name {
     return XML::XPath::Literal->new($node->getName);
 }
 
-### STRING FUNCTIONS ###
+=head2 STRING FUNCTIONS
+
+=head3 Functions On String Values
+
+=over
+
+=item *
+
+C<string()>
+
+=item *
+
+C<concat()>
+
+=item *
+
+C<substring()>
+
+=item *
+
+C<string-length()>
+
+=item *
+
+C<normalize-space()>
+
+=item *
+
+C<translate()>
+
+=back
+
+=head3 Functions Based on Substring Matching
+
+=over
+
+=item *
+
+C<contains()>
+
+=item *
+
+C<starts-with()>
+
+=item *
+
+C<substring-before()>
+
+=item *
+
+C<substring-after()>
+
+=back
+
+=head3 String Functions that Use Pattern Matching
+
+=over
+
+=item *
+
+C<matches()>
+
+=back
+
+=cut
 
 sub string {
     my $self = shift;
@@ -390,7 +503,33 @@ sub matches {
   return $str =~ /$re/ ? XML::XPath::Boolean->True : XML::XPath::Boolean->False;
 }
 
-### BOOLEAN FUNCTIONS ###
+=head2 BOOLEAN FUNCTIONS
+
+=over
+
+=item *
+
+C<boolean()>
+
+=item *
+
+C<not()>
+
+=item *
+
+C<true()>
+
+=item *
+
+C<false()>
+
+=item *
+
+C<lang()>
+
+=back
+
+=cut
 
 sub boolean {
     my $self = shift;
@@ -435,7 +574,33 @@ sub lang {
     }
 }
 
-### NUMBER FUNCTIONS ###
+=head2 NUMBER FUNCTIONS
+
+=over
+
+=item *
+
+C<number()>
+
+=item *
+
+C<sum()>
+
+=item *
+
+C<floor()>
+
+=item *
+
+C<ceiling()>
+
+=item *
+
+C<round()>
+
+=back
+
+=cut
 
 sub number {
     my $self = shift;
