@@ -1,15 +1,16 @@
 package XML::XPath::Step;
 
-$VERSION = '1.47';
-
 use XML::XPath::Parser;
 use XML::XPath::Node;
-use strict; use warnings;
+use strict;
+use warnings;
+
+our $VERSION = '1.48';
 
 # the beginnings of using XS for this file...
 # require DynaLoader;
 # use vars qw/$VERSION @ISA/;
-# $VERSION = '1.47';
+# $VERSION = '1.48';
 # @ISA = qw(DynaLoader);
 #
 # bootstrap XML::XPath::Step $VERSION;
